==> twig_casings-1.0.0.tar.gz: twig_casings/src/Twig/CasingExtension.php <==
<?php

namespace Drupal\twig_casings\Twig;

use Twig\Extension\AbstractExtension;
use Twig\TwigFilter;

/**
 * Provides Twig filters for various string casing conversions.
 */
class CasingExtension extends AbstractExtension {

  /**
   * {@inheritdoc}
   */
  public function getFilters() {
    return [
      new TwigFilter('camel_case', [$this, 'camelCase']),
      new TwigFilter('kebab_case', [$this, 'kebabCase']),
      new TwigFilter('pascal_case', [$this, 'pascalCase']),
      new TwigFilter('snake_case', [$this, 'snakeCase']),
    ];
  }

  /**
   * Converts a string to camelCase.
   *
   * @param string $string
   *   The string to convert.
   *
   * @return string
   *   The camelCase version of the string.
   */
  public function camelCase($string) {
    return lcfirst(str_replace(' ', '', ucwords(preg_replace('/[^a-zA-Z0-9]+/', ' ', $string))));
  }

  /**
   * Converts a string to kebab-case.
   *
   * @param string $string
   *   The string to convert.
   *
   * @return string
   *   The kebab-case version of the string.
   */
  public function kebabCase($string) {
    return strtolower(preg_replace('/[^a-zA-Z0-9]+/', '-', $string));
  }

  /**
   * Converts a string to PascalCase.
   *
   * @param string $string
   *   The string to convert.
   *
   * @return string
   *   The PascalCase version of the string.
   */
  public function pascalCase($string) {
    return str_replace(' ', '', ucwords(preg_replace('/[^a-zA-Z0-9]+/', ' ', $string)));
  }

  /**
   * Converts a string to snake_case.
   *
   * @param string $string
   *   The string to convert.
   *
   * @return string
   *   The snake_case version of the string.
   */
  public function snakeCase($string) {
    return strtolower(preg_replace('/[^a-zA-Z0-9]+/', '_', $string));
  }

}

==> twig_casings-1.0.2.tar.gz: twig_casings/src/Twig/CasingExtension.php <==
<?php

namespace Drupal\twig_casings\Twig;

use Twig\Extension\AbstractExtension;
use Twig\TwigFilter;

/**
 * Provides Twig filters for various string casing conversions.
 */
class CasingExtension extends AbstractExtension {

  /**
   * {@inheritdoc}
   */
  public function getFilters() {
    return [
      new TwigFilter('camel_case', [$this, 'camelCase']),
      new TwigFilter('kebab_case', [$this, 'kebabCase']),
      new TwigFilter('pascal_case', [$this, 'pascalCase']),
      new TwigFilter('snake_case', [$this, 'snakeCase']),
    ];
  }

  /**
   * Converts a string to camelCase.
   *
   * @param string $string
   *   The string to convert.
   *
   * @return string
   *   The camelCase version of the string.
   */
  public function camelCase($string) {
    return lcfirst(str_replace(' ', '', ucwords(preg_replace('/[^a-zA-Z0-9]+/', ' ', $string ?? ''))));
  }

  /**
   * Converts a string to kebab-case.
   *
   * @param string $string
   *   The string to convert.
   *
   * @return string
   *   The kebab-case version of the string.
   */
  public function kebabCase($string) {
    return strtolower(preg_replace('/[^a-zA-Z0-9]+/', '-', $string ?? ''));
  }

  /**
   * Converts a string to PascalCase.
   *
   * @param string $string
   *   The string to convert.
   *
   * @return string
   *   The PascalCase version of the string.
   */
  public function pascalCase($string) {
    return str_replace(' ', '', ucwords(preg_replace('/[^a-zA-Z0-9]+/', ' ', $string ?? '')));
  }

  /**
   * Converts a string to snake_case.
   *
   * @param string $string
   *   The string to convert.
   *
   * @return string
   *   The snake_case version of the string.
   */
  public function snakeCase($string) {
    return strtolower(preg_replace('/[^a-zA-Z0-9]+/', '_', $string ?? ''));
  }

}
